<?php

namespace Assetdocs\Assetrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Assetrequest\Http\Requests\AssetreqdtlAdminApiRequest;
use Assetdocs\Assetrequest\Interfaces\AssetreqdtlRepositoryInterface;
use Assetdocs\Assetrequest\Models\Assetreqdtl;

/**
 * Admin API controller class.
 */
class AssetreqdtlAdminApiController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.api';

    /**
     * Initialize assetreqdtl controller.
     *
     * @param type AssetreqdtlRepositoryInterface $assetreqdtl
     *
     * @return type
     */
    public function __construct(AssetreqdtlRepositoryInterface $assetreqdtl)
    {
        $this->middleware('api');
        $this->middleware('jwt.auth:admin.api');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $assetreqdtl;
        parent::__construct();
    }

    /**
     * Display a list of assetreqdtl.
     *
     * @return json
     */
    public function index(AssetreqdtlAdminApiRequest $request)
    {
        $assetreqdtls  = $this->repository
            ->pushCriteria(new \Assetdocs\Assetrequest\Repositories\Criteria\AssetreqdtlAdminCriteria())
            ->setPresenter('\\Assetdocs\\Assetrequest\\Repositories\\Presenter\\AssetreqdtlListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $assetreqdtls['code'] = 2000;
        return response()->json($assetreqdtls) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display assetreqdtl.
     *
     * @param Request $request
     * @param Model   Assetreqdtl
     *
     * @return Json
     */
    public function show(AssetreqdtlAdminApiRequest $request, Assetreqdtl $assetreqdtl)
    {
        $assetreqdtl         = $assetreqdtl->presenter();
        $assetreqdtl['code'] = 2001;
        return response()->json($assetreqdtl)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new assetreqdtl.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(AssetreqdtlAdminApiRequest $request, Assetreqdtl $assetreqdtl)
    {
        $assetreqdtl         = $assetreqdtl->presenter();
        $assetreqdtl['code'] = 2002;
        return response()->json($assetreqdtl)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new assetreqdtl.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(AssetreqdtlAdminApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $assetreqdtl          = $this->repository->create($attributes);
            $assetreqdtl          = $assetreqdtl->presenter();
            $assetreqdtl['code']  = 2004;

            return response()->json($assetreqdtl)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
;
        }
    }

    /**
     * Show assetreqdtl for editing.
     *
     * @param Request $request
     * @param Model   $assetreqdtl
     *
     * @return json
     */
    public function edit(AssetreqdtlAdminApiRequest $request, Assetreqdtl $assetreqdtl)
    {
        $assetreqdtl         = $assetreqdtl->presenter();
        $assetreqdtl['code'] = 2003;
        return response()-> json($assetreqdtl)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the assetreqdtl.
     *
     * @param Request $request
     * @param Model   $assetreqdtl
     *
     * @return json
     */
    public function update(AssetreqdtlAdminApiRequest $request, Assetreqdtl $assetreqdtl)
    {
        try {

            $attributes = $request->all();

            $assetreqdtl->update($attributes);
            $assetreqdtl         = $assetreqdtl->presenter();
            $assetreqdtl['code'] = 2005;

            return response()->json($assetreqdtl)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the assetreqdtl.
     *
     * @param Request $request
     * @param Model   $assetreqdtl
     *
     * @return json
     */
    public function destroy(AssetreqdtlAdminApiRequest $request, Assetreqdtl $assetreqdtl)
    {

        try {

            $t = $assetreqdtl->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('assetrequest::assetreqdtl.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
