<?php

namespace Assetdocs\Assetrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Assetrequest\Interfaces\AssetreqdtlRepositoryInterface;

class AssetreqdtlController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Assetreqdtl\Interfaces\AssetreqdtlRepositoryInterface $assetreqdtl
     *
     * @return type
     */
    public function __construct(AssetreqdtlRepositoryInterface $assetreqdtl)
    {
        $this->middleware('web');
        $this->setupTheme(config('theme.themes.public.theme'), config('theme.themes.public.layout'));

        $this->repository = $assetreqdtl;
        parent::__construct();
    }

    /**
     * Show assetreqdtl's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $assetreqdtls = $this->repository
            ->pushCriteria(new \Assetdocs\Assetrequest\Repositories\Criteria\AssetreqdtlPublicCriteria())
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        return $this->theme->of('assetrequest::public.assetreqdtl.index', compact('assetreqdtls'))->render();
    }

    /**
     * Show assetreqdtl.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $assetreqdtl = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('assetrequest::public.assetreqdtl.show', compact('assetreqdtl'))->render();
    }
}
