<?php

namespace Assetdocs\Assetrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Assetrequest\Http\Requests\AssetreqdtlUserWebRequest;
use Assetdocs\Assetrequest\Interfaces\AssetreqdtlRepositoryInterface;
use Assetdocs\Assetrequest\Models\Assetreqdtl;

class AssetreqdtlUserController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'web';

    /**
     * Initialize assetreqdtl controller.
     *
     * @param type AssetreqdtlRepositoryInterface $assetreqdtl
     *
     * @return type
     */
    public function __construct(AssetreqdtlRepositoryInterface $assetreqdtl)
    {
        $this->middleware('web');
        $this->middleware('auth:web');
        $this->setupTheme(config('theme.themes.user.theme'), config('theme.themes.user.layout'));

        $this->repository = $assetreqdtl;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(AssetreqdtlUserWebRequest $request)
    {
        $this->repository->pushCriteria(new \Assetdocs\Assetrequest\Repositories\Criteria\AssetreqdtlUserCriteria());
        $assetreqdtls = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('assetrequest::assetreqdtl.names').' :: ');

        return $this->theme->of('assetrequest::user.assetreqdtl.index', compact('assetreqdtls'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Assetreqdtl $assetreqdtl
     *
     * @return Response
     */
    public function show(AssetreqdtlUserWebRequest $request, Assetreqdtl $assetreqdtl)
    {
        Form::populate($assetreqdtl);

        return $this->theme->of('assetrequest::user.assetreqdtl.show', compact('assetreqdtl'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AssetreqdtlUserWebRequest $request)
    {

        $assetreqdtl = $this->repository->newInstance([]);
        Form::populate($assetreqdtl);

        return $this->theme->of('assetrequest::user.assetreqdtl.create', compact('assetreqdtl'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AssetreqdtlUserWebRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $assetreqdtl = $this->repository->create($attributes);

            return redirect(trans_url('/user/assetrequest/assetreqdtl'))
                -> with('message', trans('messages.success.created', ['Module' => trans('assetrequest::assetreqdtl.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Assetreqdtl $assetreqdtl
     *
     * @return Response
     */
    public function edit(AssetreqdtlUserWebRequest $request, Assetreqdtl $assetreqdtl)
    {

        Form::populate($assetreqdtl);

        return $this->theme->of('assetrequest::user.assetreqdtl.edit', compact('assetreqdtl'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Assetreqdtl $assetreqdtl
     *
     * @return Response
     */
    public function update(AssetreqdtlUserWebRequest $request, Assetreqdtl $assetreqdtl)
    {
        try {
            $this->repository->update($request->all(), $assetreqdtl->getRouteKey());

            return redirect(trans_url('/user/assetrequest/assetreqdtl'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('assetrequest::assetreqdtl.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(AssetreqdtlUserWebRequest $request, Assetreqdtl $assetreqdtl)
    {
        try {
            $this->repository->delete($assetreqdtl->getRouteKey());
            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('assetrequest::assetreqdtl.name')]),
                'code'     => 202,
                'redirect' => trans_url('/user/assetrequest/assetreqdtl/0'),
            ], 202);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
