<?php

namespace Assetdocs\Assetrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Assetrequest\Http\Requests\AssetreqhdAdminApiRequest;
use Assetdocs\Assetrequest\Interfaces\AssetreqhdRepositoryInterface;
use Assetdocs\Assetrequest\Models\Assetreqhd;

/**
 * Admin API controller class.
 */
class AssetreqhdAdminApiController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.api';

    /**
     * Initialize assetreqhd controller.
     *
     * @param type AssetreqhdRepositoryInterface $assetreqhd
     *
     * @return type
     */
    public function __construct(AssetreqhdRepositoryInterface $assetreqhd)
    {
        $this->middleware('api');
        $this->middleware('jwt.auth:admin.api');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $assetreqhd;
        parent::__construct();
    }

    /**
     * Display a list of assetreqhd.
     *
     * @return json
     */
    public function index(AssetreqhdAdminApiRequest $request)
    {
        $assetreqhds  = $this->repository
            ->pushCriteria(new \Assetdocs\Assetrequest\Repositories\Criteria\AssetreqhdAdminCriteria())
            ->setPresenter('\\Assetdocs\\Assetrequest\\Repositories\\Presenter\\AssetreqhdListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $assetreqhds['code'] = 2000;
        return response()->json($assetreqhds) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display assetreqhd.
     *
     * @param Request $request
     * @param Model   Assetreqhd
     *
     * @return Json
     */
    public function show(AssetreqhdAdminApiRequest $request, Assetreqhd $assetreqhd)
    {
        $assetreqhd         = $assetreqhd->presenter();
        $assetreqhd['code'] = 2001;
        return response()->json($assetreqhd)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new assetreqhd.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(AssetreqhdAdminApiRequest $request, Assetreqhd $assetreqhd)
    {
        $assetreqhd         = $assetreqhd->presenter();
        $assetreqhd['code'] = 2002;
        return response()->json($assetreqhd)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new assetreqhd.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(AssetreqhdAdminApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $assetreqhd          = $this->repository->create($attributes);
            $assetreqhd          = $assetreqhd->presenter();
            $assetreqhd['code']  = 2004;

            return response()->json($assetreqhd)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
;
        }
    }

    /**
     * Show assetreqhd for editing.
     *
     * @param Request $request
     * @param Model   $assetreqhd
     *
     * @return json
     */
    public function edit(AssetreqhdAdminApiRequest $request, Assetreqhd $assetreqhd)
    {
        $assetreqhd         = $assetreqhd->presenter();
        $assetreqhd['code'] = 2003;
        return response()-> json($assetreqhd)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the assetreqhd.
     *
     * @param Request $request
     * @param Model   $assetreqhd
     *
     * @return json
     */
    public function update(AssetreqhdAdminApiRequest $request, Assetreqhd $assetreqhd)
    {
        try {

            $attributes = $request->all();

            $assetreqhd->update($attributes);
            $assetreqhd         = $assetreqhd->presenter();
            $assetreqhd['code'] = 2005;

            return response()->json($assetreqhd)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the assetreqhd.
     *
     * @param Request $request
     * @param Model   $assetreqhd
     *
     * @return json
     */
    public function destroy(AssetreqhdAdminApiRequest $request, Assetreqhd $assetreqhd)
    {

        try {

            $t = $assetreqhd->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('assetrequest::assetreqhd.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
